#[derive(Clone, Copy)]
pub struct CheckState {
    data:u8,
}
impl CheckState {
    pub fn new() -> Self
    {
        Self {
            data:0,
        }
    }

    pub fn immediate(mut self) -> Self
    {
        self.data |= 0x80;
        self
    }

    pub fn direct(mut self) -> Self
    {
        self.data += 1;
        self.data |= 0x40;
        self
    }

    pub fn stride(mut self) -> Self
    {
        self.data += 1;
        self.data |= 0x20;
        self
    }

    pub fn apply(&mut self, other:Self)
    {
        self.data += other.data & 0x1F;
        self.data |= other.data & 0xC0;
    }

    pub fn reset(&mut self)
    {
        self.data = 0;
    }

    pub fn is_check(&self) -> bool
    {
        self.data != 0
    }

    pub fn is_immediate(&self) -> bool
    {
        (self.data & 0x80) != 0
    }

    pub fn is_direct(&self) -> bool
    {
        (self.data & 0x40) != 0
    }

    pub fn is_stride(&self) -> bool
    {
        (self.data & 0x20) != 0
    }

    pub fn count(&self) -> usize
    {
        (self.data & 0x1F) as usize
    }
}
