use crate::util::pack::{pack_u8, pack_u16};

use super::Packet;

#[derive(Clone)]
pub struct PacketChallengeListData {
    pub handle:String,
}

#[derive(Clone)]
pub struct PacketChallengeListResponse {
    pub status:u16,
    pub challenges:Vec<PacketChallengeListData>,
}
impl PacketChallengeListResponse {
    pub fn new() -> Self
    {
        Self {
            status:0,
            challenges:Vec::new(),
        }
    }
}
impl Packet for PacketChallengeListResponse {
    type Data = Self;

    fn encode(&self) -> Vec<u8>
    {
        let mut buffer = pack_u16(self.status);

        // Records
        buffer.append(&mut pack_u16(self.challenges.len() as u16));
        for challenge in &self.challenges {
            let mut chunk = Vec::new();

            // Handle
            let mut bytes = challenge.handle.as_bytes().to_vec();
            chunk.append(&mut pack_u8(bytes.len() as u8));
            chunk.append(&mut bytes);

            buffer.append(&mut chunk);
        }

        buffer
    }
}
